var _ogre_platform_8h =
[
    [ "OGRE_PLATFORM_WIN32", "_ogre_platform_8h.html#acbe1943c4784d0e38a71195b186b2648", null ],
    [ "OGRE_PLATFORM_LINUX", "_ogre_platform_8h.html#ad6ca9e6d3e2b2da8d4ee9e74a8a8f437", null ],
    [ "OGRE_PLATFORM_APPLE", "_ogre_platform_8h.html#ac1835ebd5d472ca20f5b4b3a2ddee10a", null ],
    [ "OGRE_PLATFORM_APPLE_IOS", "_ogre_platform_8h.html#a4499f0589d3e524e29fc9016a90f38d3", null ],
    [ "OGRE_PLATFORM_ANDROID", "_ogre_platform_8h.html#a696b7f8c06236aa9ce8b16569fc13985", null ],
    [ "OGRE_PLATFORM_WINRT", "_ogre_platform_8h.html#a5e538aea93661c323e7c86a88514ee48", null ],
    [ "OGRE_PLATFORM_EMSCRIPTEN", "_ogre_platform_8h.html#a813680a39abb8fa11722d6918aa73238", null ],
    [ "OGRE_COMPILER_MSVC", "_ogre_platform_8h.html#a6a94af2b19015f8d92898251ba51b894", null ],
    [ "OGRE_COMPILER_GNUC", "_ogre_platform_8h.html#ac98b9fc56eebcda33a152960bd376375", null ],
    [ "OGRE_COMPILER_CLANG", "_ogre_platform_8h.html#a1e1b3451f5070fe036ad603e9f3c4fa9", null ],
    [ "OGRE_ENDIAN_LITTLE", "_ogre_platform_8h.html#a600c868168881add7117060af46eb666", null ],
    [ "OGRE_ENDIAN_BIG", "_ogre_platform_8h.html#a077f6bc75ffd397f81a56ec2cd2838c3", null ],
    [ "OGRE_ARCHITECTURE_32", "_ogre_platform_8h.html#a37b62784316fecdf49524d6492b2f54e", null ],
    [ "OGRE_ARCHITECTURE_64", "_ogre_platform_8h.html#a338389706b17fb84162ebfa9a4c2195a", null ],
    [ "OGRE_CPU_UNKNOWN", "_ogre_platform_8h.html#ae606623294d49af88c609d5855ee418b", null ],
    [ "OGRE_CPU_X86", "_ogre_platform_8h.html#a03ad9692ca81e2302d7048c9d7695415", null ],
    [ "OGRE_CPU_PPC", "_ogre_platform_8h.html#a98616201d2102b59d9d10666f3ce8762", null ],
    [ "OGRE_CPU_ARM", "_ogre_platform_8h.html#a87dfb3e6fd0e097cfc22bcf1a936b609", null ],
    [ "OGRE_CPU_MIPS", "_ogre_platform_8h.html#ab5c7b845a9cea9c938dbcc1f9f6fec35", null ],
    [ "OGRE_CPU", "_ogre_platform_8h.html#a719f8e35fd54bc7946246292a772e5cc", null ],
    [ "OGRE_ENDIAN", "_ogre_platform_8h.html#a9af9f9208025e8051717aee67e4e7267", null ],
    [ "OGRE_COMPILER_MIN_VERSION", "_ogre_platform_8h.html#a82944247fe1c48b106e3294d05dcb307", null ],
    [ "OGRE_FORCE_INLINE", "_ogre_platform_8h.html#a6cbacd9965b6b575077a96dbf96cb23c", null ],
    [ "OGRE_FALLTHROUGH", "_ogre_platform_8h.html#af56e69ee080587cf0f82cab0908e528f", null ],
    [ "OGRE_NODISCARD", "_ogre_platform_8h.html#a11162eebee0099930c48076229cc6f04", null ],
    [ "OGRE_NORETURN", "_ogre_platform_8h.html#ad9a56ccb609a6502138fae364bf1ed39", null ],
    [ "OGRE_PLATFORM", "_ogre_platform_8h.html#ad84d3cf520c16ba4ffd3715942f7f175", null ],
    [ "OGRE_ARCH_TYPE", "_ogre_platform_8h.html#a4de9497f1c50d8052061e4870d5cdb42", null ],
    [ "OGRE_ALIGNED_DECL", "_ogre_platform_8h.html#af405686ffe3dd6aa1b9683a99e5990ed", null ],
    [ "OGRE_SIMD_ALIGNMENT", "_ogre_platform_8h.html#a30f03b7a029b1b1303e8f816b68c3368", null ],
    [ "OGRE_SIMD_ALIGNED_DECL", "_ogre_platform_8h.html#ae6883e4c8b217447e45bdaec1b1465af", null ],
    [ "OGRE_QUOTE_INPLACE", "_ogre_platform_8h.html#a9201035492049999bc82d4baa25ee090", null ],
    [ "OGRE_QUOTE", "_ogre_platform_8h.html#ab79b68443593aa3abe67d6adea621226", null ],
    [ "OGRE_WARN", "_ogre_platform_8h.html#ab61ba9272b27cdd1181dd5a18d40b750", null ],
    [ "OGRE_ENDIAN", "_ogre_platform_8h.html#a9af9f9208025e8051717aee67e4e7267", null ],
    [ "OGRE_DEFAULT_LOCALE", "_ogre_platform_8h.html#a9841c02eaa22e4d4d5067cd6cfa9b38f", null ],
    [ "OGRE_BUILD_SUFFIX", "_ogre_platform_8h.html#a922bb8a4073c0e5b0b48acf831b90a64", null ],
    [ "DECL_MALLOC", "_ogre_platform_8h.html#aa1730b3ff27777dab53a340f23844db4", null ],
    [ "Ogre::uint32", "namespace_ogre.html#a8f2f90fa4c83c075e3fae75456ae5ded", null ],
    [ "Ogre::uint16", "namespace_ogre.html#a2a820cf8746c0f12999d2416c767f55d", null ],
    [ "Ogre::uint8", "namespace_ogre.html#a135bdde033ee93f327917c6ff578d46c", null ],
    [ "Ogre::uint64", "namespace_ogre.html#a60635457b0b97495b34737baa4fb3f64", null ],
    [ "Ogre::int32", "namespace_ogre.html#a6e6e978d04d35e4351576d3f6f3e2364", null ],
    [ "Ogre::int16", "namespace_ogre.html#a355345c182bde9095610b63a9fd69376", null ],
    [ "Ogre::int8", "namespace_ogre.html#a6519f6582ca047f2c0ae0bb056bb9134", null ],
    [ "Ogre::int64", "namespace_ogre.html#a400c2fa3db9a7c0c34de0635b01ab3b6", null ]
];